import React from 'react';
import { graphql, } from 'react-apollo';
import gql from 'graphql-tag';
import PropTypes from 'prop-types';

import styles from './project-styles';

const Project = ({ project, }) => (
  <div>
    {project ? (
      <div>
        {project.name}
        {project.metadata.js.modules.map(({ name, version, }) => (
          <div key={name} className={styles.module}>
            {name}: {version}
          </div>
        ))}
      </div>
    ) : null}
  </div>
);

Project.propTypes = {
  project: PropTypes.shape({
    id: PropTypes.string,
    name: PropTypes.string,
    metadata: PropTypes.shape({
      projectType: PropTypes.string,
      js: PropTypes.shape({
        modules: PropTypes.arrayOf(
          PropTypes.shape({
            name: PropTypes.string,
            version: PropTypes.string,
          })
        ),
      }),
    }),
  }),
};

Project.defaultProps = {
  project: null,
};

const PROJECT_GQL = gql`
query Project($name: String!) {
  project(name: $name) {
    id
    name
    metadata {
      projectType
      js {
        modules(type: "direct") {
          name
          version
        }
      }
    }
  }
}
`;

export default graphql(PROJECT_GQL, {
  props: ({ data: { project, }, }) => ({
    project: project || null,
  }),
  options: ({ match, }) => ({
    variables: {
      name: match.params.name,
    },
  }),
})(Project);
