/* eslint no-underscore-dangle: 0 */
import assign from 'lodash.assign';
import get from 'lodash.get';

import Projects from '../db/projects';

import TextIndexStorage from '../data-managers/text-index-storage';
import ComponentUsageStorage from '../data-managers/component-usage-storage';
import ClassStorage from '../data-managers/class-storage';
import NodeDependencyStorage from '../data-managers/node-dependency-storage';

export default {
  Query: {
    projects() {
      return Projects.find().fetch().map(pr => assign(pr, {
        id: pr._id,
      }));
    },
    project(root, args) {
      const project = Projects.findOne(args);
      return assign(project, {
        id: project._id,
      });
    },
    search(root, { text, }) {
      return {
        text,
      };
    },
    classes(root, { name, project, }) {
      return ClassStorage.getByName(name, project);
    },
    components(root, { name, project, }) {
      return ClassStorage.getByName(name, project).filter(
        pr => get(pr, 'metadata.react') === true
      );
    },
    dependencies(root, { name, project, type, }) {
      return NodeDependencyStorage.getByName(name, project, type);
    },
  },
  ProjectMetadataJS: {
    modules({ modules, }, { type, }) {
      if (type && type.length > 0) {
        return modules.filter(m => m.type === type);
      }
      return modules;
    },
  },
  SearchResult: {
    text(root) {
      return TextIndexStorage.query(root.text).map(pr => assign(pr, {
        id: pr._id,
      }));
    },
    componentUsage(root) {
      return ComponentUsageStorage.query(root.text).map(pr => assign(pr, {
        id: pr._id,
      }));
    },
    classes(root) {
      return ClassStorage.query(root.text).map(pr => assign(pr, {
        id: pr._id,
      }));
    },
    dependencies(root) {
      return NodeDependencyStorage.queryRollup(root.text).map(pr => assign(pr, {
        id: pr._id,
      }));
    },
  },
};
