export default [`
type ProjectMetadataNodeModule {
  name: String!
  version: String!
  type: String
  requestedVersion: String
}

type ProjectNodeRunOutput {
  stdout: String
  stderr: String
}

type ProjectNode {
  build: ProjectNodeRunOutput
  test: ProjectNodeRunOutput
}

type ProjectMetadataJS {
  modules(type: String): [ProjectMetadataNodeModule]
  builtVersion: String
  node: ProjectNode
}

type ProjectMetadata {
  projectType: String
  js: ProjectMetadataJS
}

type ProjectChild {
  localPath: String!
  name: String!
}

type Project {
  id: String!
  type: String!
  name: String!
  localPath: String!
  metadata: ProjectMetadata
  children: [ProjectChild]
}

type File {
  id: String!
  name: String!
  localPath: String!
  relativePath: String!
  mimeType: String!
  type: String!
}

type ComponentUsage {
  id: String!
  start: Int!
  end: Int!
  type: String!
  name: String!
  base: String!
  attributes: [String]!
  snippet: String!
  project: String!
  package: String!
  fileName: String!
  codeURL: String!
}

type DocGenPropType {
  name: String
}

type DocGenPropDefaultValue {
  value: String
  computed: Boolean
}

type DocGenProp {
  type: DocGenPropType
  required: Boolean
  description: String
  defaultValue: DocGenPropDefaultValue
  name: String
}

type DocGenParam {
  name: String
  description: String
  type: String
}

type DocGenReturns {
  description: String
  type: String
}

type DocGenMethod {
  name: String
  docblock: String
  description: String
  params: [DocGenParam]
  returns: DocGenReturns
}

type DocGen {
  description: String
  methods: [DocGenMethod]
}

type JSDocTag {
  title: String
  description: String
  type: String
  name: String
}

type JSDoc {
  description: String
  tags: [JSDocTag]
}

type ClassMethod {
  start: Int!
  end: Int!
  type: String!
  name: String!
  kind: String!
  snippet: String!
  jsDoc: JSDoc
}

type ClassMetadata {
  react: Boolean
  stateless: Boolean
}

type Class {
  id: String!
  start: Int!
  end: Int!
  type: String!
  name: String!
  metadata: ClassMetadata!
  snippet: String!
  project: String!
  fileName: String!
  codeURL: String!
  methods: [ClassMethod]!
  jsDoc: JSDoc
  superClass: String!
}

type SearchResultText {
  id: String!
  start: Int!
  end: Int!
  type: String!
  text: String!
  snippet: String!
  project: String!
  fileName: String!
  codeURL: String!
}

type NodeDependency {
  project: String
  name: String
  version: String
  type: String
  requestedVersion: String
}

type NodeDependencyRollupGroup {
  version: String!
  projects: [String]!
}

type NodeDependencyRollup {
  name: String!
  direct: [NodeDependencyRollupGroup]!
  development: [NodeDependencyRollupGroup]!
  indirect: [NodeDependencyRollupGroup]!
}

type SearchResult {
  text: [SearchResultText]
  componentUsage: [ComponentUsage]
  classes: [Class]
  dependencies: [NodeDependencyRollup]
}

type Query {
  projects: [Project]
  project(name: String!): Project
  search(text: String): SearchResult
  classes(name: String, project: String): [Class]
  components(name: String, project: String): [Class]
  dependencies(name: String, project: String, type: String): [NodeDependency]
}
`,
];
