/* eslint class-methods-use-this: 0, no-underscore-dangle: 0 */

import { Mongo, } from 'meteor/mongo';
import get from 'lodash.get';
import merge from 'lodash.merge';

import Base from './base';
import PackageMemoryStorage from './package-memory-storage';

const ComponentIndex = new Mongo.Collection('class_index');

class ClassStorage extends Base {
  startup() {
    ComponentIndex._ensureIndex({
      name: 'text',
    });
    ComponentIndex._ensureIndex({
      name: 1,
    });
    ComponentIndex._ensureIndex({
      project: 1,
    });
  }

  beforeProject(runID, project) {
    ComponentIndex.remove({
      project,
    });
  }

  addFile(data) {
    get(data, 'metadata.js.features', []).forEach((feature) => {
      if (feature.type === 'class') {
        ComponentIndex.insert(merge(feature, {
          project: data.project,
          fileName: data.name,
          docgen: get(data, 'metadata.js.docgen'),
          codeURL: PackageMemoryStorage.getRepositoryFileURL(
            data.project,
            data.name,
            feature.start,
            feature.end
          ),
        }));
      }
    });
  }

  getByName(name, project) {
    const q = {
      name,
    };
    if (project) {
      q.package = project;
    }
    return ComponentIndex.find(q).fetch();
  }

  query(text) {
    return ComponentIndex.find(({
      $text: {
        $search: text,
      },
    })).fetch();
  }
}

ClassStorage.singleton = new ClassStorage();

export default ClassStorage.singleton;
