/* eslint class-methods-use-this: 0, no-underscore-dangle: 0 */

import { Mongo, } from 'meteor/mongo';
import get from 'lodash.get';
import merge from 'lodash.merge';

import Base from './base';
import PackageMemoryStorage from './package-memory-storage';

const ComponentUsageIndex = new Mongo.Collection('component_usage');

class ComponentUsageStorage extends Base {
  startup() {
    ComponentUsageIndex._ensureIndex({
      name: 'text',
    });
    ComponentUsageIndex._ensureIndex({
      name: 1,
    });
    ComponentUsageIndex._ensureIndex({
      name: 1,
      package: 1,
    });
    ComponentUsageIndex._ensureIndex({
      project: 1,
    });
  }

  beforeProject(runID, project) {
    ComponentUsageIndex.remove({
      project,
    });
  }

  addFile(data) {
    const imports = {};
    get(data, 'metadata.js.features', []).forEach((feature) => {
      if (feature.type === 'import') {
        get(feature, 'keys').forEach((key) => {
          imports[key] = feature.from;
        });
      }
    });

    get(data, 'metadata.js.features', []).forEach((feature) => {
      if (feature.type === 'jsx-usage') {
        ComponentUsageIndex.insert(merge(feature, {
          project: data.project,
          fileName: data.name,
          package: imports[feature.name],
          codeURL: PackageMemoryStorage.getRepositoryFileURL(
            data.project,
            data.name,
            feature.start,
            feature.end
          ),
        }));
      }
    });
  }

  getByName(name, pkgName) {
    const q = {
      name,
    };
    if (pkgName) {
      q.package = pkgName;
    }
    return ComponentUsageIndex.find(q);
  }

  query(text) {
    return ComponentUsageIndex.find(({
      $text: {
        $search: text,
      },
    })).fetch();
  }
}

ComponentUsageStorage.singleton = new ComponentUsageStorage();

export default ComponentUsageStorage.singleton;
