import FileStorage from './file-storage';
import ProjectStorage from './project-storage';
import TextIndexStorage from './text-index-storage';
import PackageMemoryStorage from './package-memory-storage';
import ComponentUsageStorage from './component-usage-storage';
import ClassStorage from './class-storage';
import NodeDependencyStorage from './node-dependency-storage';

const managers = [
  PackageMemoryStorage,
  ProjectStorage,
  FileStorage,
  TextIndexStorage,
  ClassStorage,
  ComponentUsageStorage,
  NodeDependencyStorage,
];

managers.forEach(mgr => mgr.startup());

export default (data) => {
  managers.forEach((mgr) => {
    if (data.signal) {
      if (data.signal === 'startRun') {
        mgr.startRun(data.runID);
      }
      if (data.signal === 'endRun') {
        mgr.endRun(data.runID);
      }
      if (data.signal === 'beforeProject') {
        mgr.beforeProject(
          data.runID,
          data.name
        );
      }
      if (data.signal === 'afterProject') {
        mgr.afterProject(
          data.runID,
          data.name
        );
      }
    } else {
      if (data.type === 'Project') {
        mgr.addProject(data);
      }
      if (data.type === 'File') {
        mgr.addFile(data);
      }
    }
  });
};
