/* eslint class-methods-use-this: 0, no-underscore-dangle: 0 */

import { Mongo, } from 'meteor/mongo';
import get from 'lodash.get';
import merge from 'lodash.merge';
import keys from 'lodash.keys';

import Base from './base';

const NodeDependencyIndex = new Mongo.Collection('node_dependency');

class ComponentStorage extends Base {
  startup() {
    NodeDependencyIndex._ensureIndex({
      name: 'text',
    });
    NodeDependencyIndex._ensureIndex({
      name: 1,
    });
    NodeDependencyIndex._ensureIndex({
      project: 1,
    });
  }

  beforeProject(runID, project) {
    NodeDependencyIndex.remove({
      project,
    });
  }

  addProject(data) {
    get(data, 'metadata.js.modules', []).forEach((module) => {
      NodeDependencyIndex.insert(merge(module, {
        project: data.name,
      }));
    });
  }

  getByName(name, project, type) {
    const q = {};
    if (name) {
      q.name = name;
    }
    if (project) {
      q.project = project;
    }
    if (type) {
      q.type = type;
    }
    return NodeDependencyIndex.find(q).fetch();
  }

  rollupReport(dependencies) {
    const byName = {};
    dependencies.forEach(({ name, version, project, type, }) => {
      if (byName[name] === undefined) {
        byName[name] = {
          direct: [],
          development: [],
          indirect: [],
        };
      }
      let arr = byName[name].indirect;
      if (type === 'dev') {
        arr = byName[name].development;
      }
      if (type === 'direct') {
        arr = byName[name].direct;
      }

      let found = null;
      arr.forEach((item) => {
        if (item.version === version) {
          found = item;
        }
      });
      if (!found) {
        found = {
          version,
          projects: [],
        };
        arr.push(found);
      }

      found.projects.push(project);
    });
    return keys(byName).map(k => merge(byName[k], {
      name: k,
    }));
  }

  query(text) {
    return NodeDependencyIndex.find(({
      $text: {
        $search: text,
      },
    })).fetch();
  }

  queryRollup(text) {
    return this.rollupReport(this.query(text));
  }
}

ComponentStorage.singleton = new ComponentStorage();

export default ComponentStorage.singleton;
