/* eslint class-methods-use-this: 0 */

import get from 'lodash.get';

import Base from './base';
import Projects from '../db/projects';

class PackageMemoryStorage extends Base {
  startup() {
    this.lookup = {};
  }

  addProject(project) {
    const jsonText = get(project, 'metadata.js.packageJSONText');
    if (jsonText) {
      this.lookup[project.name] = JSON.parse(jsonText);
    }
  }

  getPackage(name) {
    if (!this.lookup[name]) {
      const project = Projects.findOne({
        name,
      });
      if (project) {
        this.addProject(project);
      }
    }
    return this.lookup[name];
  }

  getRepository(name) {
    const packageInfo = this.getPackage(name);
    return packageInfo ? packageInfo.repository : null;
  }

  // https://github.com/orsa-actual/orsa/tree/master/packages/orsa-test-react/fixtures/test1/project2
  // https://github.com/orsa-actual/orsa/blob/master/packages/orsa-test-react/fixtures/test1/project2/src/simple.js
  // https://github.com/orsa-actual/orsa/blob/master/packages/orsa-test-react/fixtures/test1/project2/src/simple.js#L4-L6

  getRepositoryFileURL(projectName, filePath, start, end) {
    let url = this.getRepository(projectName);
    if (url && filePath) {
      url += `/${filePath}`;
      if (url.match(/github/)) {
        url.replace(/\/tree\//, '/blob/');
      }
      if (start && end) {
        url += `#L${start}-L${end}`;
      } else if (start) {
        url += `#L${start}`;
      }
    }
    return url;
  }
}

PackageMemoryStorage.singleton = new PackageMemoryStorage();

export default PackageMemoryStorage.singleton;
