/* eslint class-methods-use-this: 0, no-underscore-dangle: 0 */

import { Mongo, } from 'meteor/mongo';
import get from 'lodash.get';
import merge from 'lodash.merge';

import Base from './base';
import PackageMemoryStorage from './package-memory-storage';

const TextIndex = new Mongo.Collection('text_index');

class TextIndexStorage extends Base {
  startup() {
    TextIndex._ensureIndex({
      text: 'text',
    });
  }

  beforeProject(runID, project) {
    TextIndex.remove({
      project,
    });
  }

  addFile(data) {
    get(data, 'metadata.js.features', []).forEach((feature) => {
      if (feature.type === 'jsx-text') {
        TextIndex.insert(merge(feature, {
          project: data.project,
          fileName: data.name,
          codeURL: PackageMemoryStorage.getRepositoryFileURL(
            data.project,
            data.name,
            feature.start,
            feature.end
          ),
        }));
      }
    });
  }

  query(text) {
    return TextIndex.find(({
      $text: {
        $search: text,
      },
    })).fetch();
  }
}

TextIndexStorage.singleton = new TextIndexStorage();

export default TextIndexStorage.singleton;
